@@ -4,7 +4,6 @@
 # to make it harder for the user to import the wrong thing without realizing.
 from __future__ import unicode_literals
 
-import django
 from django.conf import settings
 from django.test import testcases
 from django.test.client import Client as DjangoClient
@@ -223,9 +222,9 @@ class APITestCase(testcases.TestCase):
     client_class = APIClient
 
 
-if django.VERSION >= (1, 4):
-    class APISimpleTestCase(testcases.SimpleTestCase):
-        client_class = APIClient
+class APISimpleTestCase(testcases.SimpleTestCase):
+    client_class = APIClient
 
-    class APILiveServerTestCase(testcases.LiveServerTestCase):
-        client_class = APIClient
+
+class APILiveServerTestCase(testcases.LiveServerTestCase):
+    client_class = APIClient
