@@ -1,6 +1,6 @@
-
 from django.conf.urls import url
 from django.contrib.auth.models import User
+from django.test import override_settings
 
 from rest_framework.authentication import TokenAuthentication
 from rest_framework.authtoken.models import Token
@@ -20,10 +20,8 @@ class MyMiddleware(object):
         return response
 
 
+@override_settings(ROOT_URLCONF='tests.test_middleware')
 class TestMiddleware(APITestCase):
-
-    urls = 'tests.test_middleware'
-
     def test_middleware_can_access_user_when_processing_response(self):
         user = User.objects.create_user('john', 'john@example.com', 'password')
         key = 'abcd1234'
