@@ -6,7 +6,7 @@ from io import BytesIO
 from django.conf.urls import url
 from django.contrib.auth.models import User
 from django.shortcuts import redirect
-from django.test import TestCase
+from django.test import TestCase, override_settings
 
 from rest_framework.decorators import api_view
 from rest_framework.response import Response
@@ -44,9 +44,8 @@ urlpatterns = [
 ]
 
 
+@override_settings(ROOT_URLCONF='tests.test_testing')
 class TestAPITestClient(TestCase):
-    urls = 'tests.test_testing'
-
     def setUp(self):
         self.client = APIClient()
 
