@@ -21,7 +21,7 @@ class WriteOnlyFieldTests(TestCase):
         }
         serializer = self.Serializer(data=data)
         self.assertTrue(serializer.is_valid())
-        self.assertEquals(serializer.validated_data, data)
+        self.assertEqual(serializer.validated_data, data)
 
     def write_only_fields_are_not_present_on_output(self):
         instance = {
@@ -29,4 +29,4 @@ class WriteOnlyFieldTests(TestCase):
             'password': '123'
         }
         serializer = self.Serializer(instance)
-        self.assertEquals(serializer.data, {'email': 'foo@example.com'})
+        self.assertEqual(serializer.data, {'email': 'foo@example.com'})
